==> download.php?file=Net2Plan-0.3.0.zip: com/net2plan/internal/AttributeMap.java <==
/*******************************************************************************
 * Copyright (c) 2013-2015 Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * Contributors:
 *     Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza - initial API and implementation
 ******************************************************************************/
package com.net2plan.internal;

import java.util.Map;
import java.util.TreeMap;

/**
 * Extends <code>TreeMap</code> to forbid 'null or empty' keys.
 * 
 * @author Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza
 * @since 0.3.0
 */
public class AttributeMap extends TreeMap<String, String>
{
	private static final long serialVersionUID = 1L;
	
	/**
	 * Default constructor.
	 * 
	 * @since 0.3.0
	 */
	public AttributeMap()
	{
		super();
	}

	/**
	 * Constructor that copies the value set of the input map.
	 * 
	 * @param m Map to be copied (if null, it will be initialized as empty)
	 * @since 0.3.0
	 */
	public AttributeMap(Map<String, String> m)
	{
		this();

		if (m == null) return;
		for (Map.Entry<String, String> entry : m.entrySet()) put(entry.getKey(), entry.getValue());
	}

	@Override
	public String put(String key, String value)
	{
		if (key == null || key.isEmpty()) throw new RuntimeException("Key cannot be null or empty");
		return super.put(key, value);
	}
	
	@Override
	public void putAll(Map<? extends String, ? extends String> m)
	{
		if (m == null) { clear(); return; }
		super.putAll(m);
	}
}

==> download.php?file=Net2Plan-0.3.1.zip: com/net2plan/internal/AttributeMap.java <==
/*******************************************************************************
 * Copyright (c) 2013-2015 Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * Contributors:
 *     Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza - initial API and implementation
 ******************************************************************************/
package com.net2plan.internal;

import java.util.Map;
import java.util.TreeMap;

/**
 * Extends {@code TreeMap} to forbid 'null or empty' keys.
 * 
 * @author Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza
 * @since 0.3.0
 */
public class AttributeMap extends TreeMap<String, String>
{
	/**
	 * Default constructor.
	 * 
	 * @since 0.3.0
	 */
	public AttributeMap()
	{
		super();
	}

	/**
	 * Constructor that copies the value set of the input map.
	 * 
	 * @param m Map to be copied (if null, it will be initialized as empty)
	 * @since 0.3.0
	 */
	public AttributeMap(Map<String, String> m)
	{
		this();

		if (m == null) return;
		for (Map.Entry<String, String> entry : m.entrySet()) put(entry.getKey(), entry.getValue());
	}

	@Override
	public String put(String key, String value)
	{
		if (key == null || key.isEmpty()) throw new RuntimeException("Key cannot be null or empty");
		return super.put(key, value);
	}
	
	@Override
	public void putAll(Map<? extends String, ? extends String> m)
	{
		if (m == null) { clear(); return; }
		super.putAll(m);
	}
}
